==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/sites/lang/sites_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'Čakajúce',
	'articles_meme_auteur' => 'Všetky články tohto autora',
	'articles_off' => 'Bloky',
	'articles_publie' => 'Publikované',
	'articles_refuse' => 'Zamietnuté',
	'articles_tous' => 'Všetky',
	'aucun_article_syndic' => 'Žiaden syndikovaný článok',
	'avis_echec_syndication_01' => 'Syndikácia zlyhala: buď sa vybrané backendové rozhranie nedá čítať, alebo neobsahuje žiadne články.',
	'avis_echec_syndication_02' => 'Syndikácia sa nepodarila: nepodarilo sa nájsť backendový súbor tejto stránky.',
	'avis_site_introuvable' => 'Stránka sa nenašla',
	'avis_site_syndique_probleme' => 'Upozornenie: pri syndikácii tejto stránky sa vyskytol problém; systém je dočasne narušený. Skontrolujte adresu syndikačného súboru tejto stránky (<b>@url_syndic@</b>) a skúste získať informácie znova.',
	'avis_sites_probleme_syndication' => 'Pri týchto stránkach sa vyskytol problém so syndikáciou',
	'avis_sites_syndiques_probleme' => 'Pri týchto syndikovaných stránkach sa vyskytol problém',

	// B
	'bouton_exporter' => 'Exportovať',
	'bouton_importer' => 'Nahrať',
	'bouton_radio_modere_posteriori' => 'Kontrola po publikovaní',
	'bouton_radio_modere_priori' => 'Kontrola pred publikovaním',
	'bouton_radio_non_syndication' => 'Žiadna syndikácia',
	'bouton_radio_syndication' => 'Syndikácia:',

	// C
	'confirmer_purger_syndication' => 'Určite chcete odstrániť všetky články z tejto stránky?',

	// E
	'entree_adresse_fichier_syndication' => 'Adresa syndikačného súboru:',
	'entree_adresse_site' => '<b>Adresa stránky</b> [Povinné]',
	'entree_description_site' => 'Opis stránky',
	'erreur_fichier_format_inconnu' => 'Formát súboru @fichier@ nie je podporovaný.',
	'erreur_fichier_incorrect' => 'Súbor sa nedá čítať.',

	// F
	'form_prop_nom_site' => 'Názov stránky',

	// I
	'icone_article_syndic' => 'Syndikovaný článok',
	'icone_articles_syndic' => 'Syndikované články',
	'icone_controler_syndication' => 'Publikovanie syndikovaných článkov',
	'icone_modifier_site' => 'Upraviť tieto stránky',
	'icone_referencer_nouveau_site' => 'Vytvoriť odkaz na novú stránku',
	'icone_site_reference' => 'Odkazované stránky',
	'icone_supprimer_article' => 'Odstrániť tento článok',
	'icone_supprimer_articles' => 'Odstrániť tieto články',
	'icone_valider_article' => 'Schváliť tento článok',
	'icone_valider_articles' => 'Schváliť tieto články',
	'icone_voir_sites_references' => 'Zobraziť linky',
	'info_1_site_importe' => '1 stránka sa nahrala',
	'info_a_valider' => '[čaká na schválenie]',
	'info_aucun_site_importe' => 'Nenahrala sa žiadna stránka',
	'info_bloquer' => 'zablokovať',
	'info_bloquer_lien' => 'Zablokovať tento odkaz',
	'info_derniere_syndication' => 'Posledná syndikácia bola vykonaná',
	'info_liens_syndiques_1' => 'syndikované odkazy',
	'info_liens_syndiques_2' => 'čaká na schválenie.',
	'info_nb_sites_importes' => '@nb@ stránok sa nahralo',
	'info_nom_site_2' => '<b>Názov stránky</b> [Povinné]',
	'info_panne_site_syndique' => 'Syndikovaná stránka mimo prevádzky',
	'info_probleme_grave' => 'chyba u',
	'info_question_proposer_site' => 'Kto môže navrhovať stránky, na ktoré sa odkazuje?',
	'info_retablir_lien' => 'Obnoviť tento odkaz',
	'info_site_attente' => 'Stránka, ktorá čaká na schválenie',
	'info_site_propose' => 'Stránka odoslaná:',
	'info_site_reference' => 'Odkazované stránky online',
	'info_site_refuse' => 'Zamietnutá stránka',
	'info_site_syndique' => 'Táto stránka je syndikovaná.',
	'info_site_valider' => 'Stránky, ktoré čakajú na schválenie',
	'info_sites_referencer' => 'Vložiť odkaz na stránku',
	'info_sites_refuses' => 'Zamietnuté stránky',
	'info_statut_site_1' => 'Táto stránka je:',
	'info_statut_site_2' => 'Publikovaná',
	'info_statut_site_3' => 'Odoslaná',
	'info_statut_site_4' => 'Do koša',
	'info_syndication' => 'syndikácia:',
	'info_syndication_articles' => 'článok (-nky)',
	'item_bloquer_liens_syndiques' => 'Zablokovať syndikované odkazy na overenie',
	'item_gerer_annuaire_site_web' => 'Riadiť priečinok s internetovými stránkami',
	'item_non_bloquer_liens_syndiques' => 'Neblokovať odkazy zo syndikácie',
	'item_non_gerer_annuaire_site_web' => 'Deaktivovať priečinok s internetovými stránkami',
	'item_non_utiliser_syndication' => 'Nepoužívať automatickú syndikáciu',
	'item_utiliser_syndication' => 'Používať automatickú syndikáciu',

	// L
	'label_exporter_avec_mots_cles_1' => 'Exportovať kľúčové slová vo forme tagov',
	'label_exporter_id_parent' => 'Exportovať stránky z rubriky',
	'label_exporter_publie_seulement_1' => 'Exportovať iba publikované stránky',
	'label_fichier_import' => 'Súbor HTML',
	'label_importer_les_tags_1' => 'Nahrať tagy vo forme kľúčových slov',
	'label_importer_statut_publie_1' => 'Automaticky publikovať stránky',
	'lien_mise_a_jour_syndication' => 'Aktualizovať teraz',
	'lien_nouvelle_recuperation' => 'Pokúsiť sa znova získať dáta',
	'lien_purger_syndication' => 'Odstrániť všetky syndikované články',

	// N
	'nombre_articles_syndic' => '@nb@ syndikovaných článkov',

	// S
	'statut_off' => 'Odstránené',
	'statut_prop' => 'Čaká',
	'statut_publie' => 'Publikovaný',
	'syndic_choix_moderation' => 'Čo urobiť s odkazmi z tejto stránky?',
	'syndic_choix_oublier' => 'Čo urobiť s odkazmi, ktoré už viac neexistujú v syndikačnom súbore?',
	'syndic_choix_resume' => 'Niektoré stránky ponúkajú úplné texty svojich článkov. Ak je k dispozícii úplný text, chcete syndikovať:',
	'syndic_lien_obsolete' => 'zastaraný odkaz',
	'syndic_option_miroir' => 'zablokovať ich automaticky',
	'syndic_option_oubli' => 'vymazať ich (po @mois@ mesiacoch)',
	'syndic_option_resume_non' => 'celý obsah článkov (formát HTML)',
	'syndic_option_resume_oui' => 'iba zhrnutie (ako text)',
	'syndic_options' => 'Možnosti syndikácie:',

	// T
	'texte_expliquer_export_bookmarks' => 'Zoznam svojich záložiek môžete exportovať, aby ste ich nahrali do svojho prehliadača alebo internetovej služby na správu záložiek',
	'texte_expliquer_import_bookmarks' => 'Zoznam záložiek vo formáte HTML môžete nahrať zo svojho prehliadača alebo internetovej služby na správu záložiek.',
	'texte_liens_sites_syndiques' => 'Odkazy prichádzajúce zo syndikovaných stránok by mohli
			byť zablokované dopredu; nasledujúce
			nastavenie uvádza predvolené nastavenie
			syndikovaných stránok po ich vytvorení. Potom
			sa aj tak
			dá zablokovať každý odkaz samostatne alebo
			vybrať stránky, z ktorých sa budú prichádzajúce odkazy blokovať automaticky.',
	'texte_messages_publics' => 'Verejné príspevky k článku:',
	'texte_non_fonction_referencement' => 'Môžete sa rozhodnúť nepoužívať túto automatizovanú funkciu a zobrazovať prvky z danej stránky sami.',
	'texte_referencement_automatique' => '<b>Automatické odkazovanie na stránky</b><br />Môžete rýchlo vložiť odkaz na stránku, tak, že uvediete jej adresu alebo adresu jej syndikačného súboru. SPIP automaticky získa údaje o tejto stránke (názov, popis, a pod.).',
	'texte_referencement_automatique_verifier' => 'Pred uložením, prosím, skontrolujte údaje z <tt>@url@</tt>.',
	'texte_syndication' => 'Zoznam nových funkcií sa dá získať automaticky, keď to stránka povoľuje. Na to musíte aktivovať syndikáciu. 
  <blockquote><i>Niektorí poskytovatelia webhostingu deaktivujú túto funkciu; 
 v tom prípade nemôžete využívať syndikáciu obsahu
   zo svojej stránky.</i></blockquote>',
	'titre_articles_syndiques' => 'Syndikované články stiahnuté z tejto stránky',
	'titre_dernier_article_syndique' => 'Najnovšie syndikované články',
	'titre_exporter_bookmarks' => 'Exportovať záložky',
	'titre_importer_bookmarks' => 'Nahrať záložky',
	'titre_importer_exporter_bookmarks' => 'Nahrať a exportovať záložky',
	'titre_page_sites_tous' => 'Stránky, na ktoré odkazujete',
	'titre_referencement_sites' => 'Odkazovanie na stránky a ich syndikácia',
	'titre_site_numero' => 'ČÍSLO STRÁNKY:',
	'titre_sites_proposes' => 'Odoslané stránky',
	'titre_sites_references_rubrique' => 'Odkazované stránky v tejto rubrike',
	'titre_sites_syndiques' => 'Syndikované stránky',
	'titre_sites_tous' => 'Stránky, na ktoré odkazujete',
	'titre_syndication' => 'Syndikácia stránok',
	'tout_voir' => 'Zobraziť všetky syndikované články',

	// U
	'un_article_syndic' => '1 syndikovaný článok'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/sites/lang/sites_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'Čakajúce',
	'articles_meme_auteur' => 'Všetky články tohto autora',
	'articles_off' => 'Bloky',
	'articles_publie' => 'Publikované',
	'articles_refuse' => 'Zamietnuté',
	'articles_tous' => 'Všetky',
	'aucun_article_syndic' => 'Žiaden syndikovaný článok',
	'avis_echec_syndication_01' => 'Syndikácia zlyhala: buď sa vybrané backendové rozhranie nedá čítať, alebo neobsahuje žiadne články.',
	'avis_echec_syndication_02' => 'Syndikácia sa nepodarila: nepodarilo sa nájsť backendový súbor tejto stránky.',
	'avis_site_introuvable' => 'Stránka sa nenašla',
	'avis_site_syndique_probleme' => 'Upozornenie: pri syndikácii tejto stránky sa vyskytol problém; systém je dočasne narušený. Skontrolujte adresu syndikačného súboru tejto stránky (<b>@url_syndic@</b>) a skúste získať informácie znova.',
	'avis_sites_probleme_syndication' => 'Pri týchto stránkach sa vyskytol problém so syndikáciou',
	'avis_sites_syndiques_probleme' => 'Pri týchto syndikovaných stránkach sa vyskytol problém',

	// B
	'bouton_exporter' => 'Exportovať',
	'bouton_importer' => 'Nahrať',
	'bouton_radio_modere_posteriori' => 'Kontrola po publikovaní',
	'bouton_radio_modere_priori' => 'Kontrola pred publikovaním',
	'bouton_radio_non_syndication' => 'Žiadna syndikácia',
	'bouton_radio_syndication' => 'Syndikácia:',

	// C
	'confirmer_purger_syndication' => 'Určite chcete odstrániť všetky články z tejto stránky?',

	// E
	'entree_adresse_fichier_syndication' => 'Adresa syndikačného súboru:',
	'entree_adresse_site' => '<b>Adresa stránky</b> [Povinné]',
	'entree_description_site' => 'Opis stránky',
	'erreur_fichier_format_inconnu' => 'Formát súboru @fichier@ nie je podporovaný.',
	'erreur_fichier_incorrect' => 'Súbor sa nedá čítať.',

	// F
	'form_prop_nom_site' => 'Názov stránky',

	// I
	'icone_article_syndic' => 'Syndikovaný článok',
	'icone_articles_syndic' => 'Syndikované články',
	'icone_controler_syndication' => 'Publikovanie syndikovaných článkov',
	'icone_modifier_site' => 'Upraviť tieto stránky',
	'icone_referencer_nouveau_site' => 'Vytvoriť odkaz na novú stránku',
	'icone_site_reference' => 'Odkazované stránky',
	'icone_supprimer_article' => 'Odstrániť tento článok',
	'icone_supprimer_articles' => 'Odstrániť tieto články',
	'icone_valider_article' => 'Schváliť tento článok',
	'icone_valider_articles' => 'Schváliť tieto články',
	'icone_voir_sites_references' => 'Zobraziť linky',
	'info_1_article_syndique' => '1 syndikovaný článok',
	'info_1_site' => '1 stránka',
	'info_1_site_importe' => '1 stránka sa nahrala',
	'info_a_valider' => '[čaká na schválenie]',
	'info_aucun_article_syndique' => 'Žiadne syndikované články',
	'info_aucun_site' => 'Žiadne odkazy na stránky',
	'info_aucun_site_importe' => 'Nenahrala sa žiadna stránka',
	'info_bloquer' => 'zablokovať',
	'info_bloquer_lien' => 'Zablokovať tento odkaz',
	'info_derniere_syndication' => 'Posledná syndikácia bola vykonaná',
	'info_liens_syndiques_1' => 'syndikované odkazy',
	'info_liens_syndiques_2' => 'čaká na schválenie.',
	'info_nb_articles_syndiques' => 'syndikovaných článkov: @nb@',
	'info_nb_sites' => 'stránok: @nb@ ',
	'info_nb_sites_importes' => '@nb@ stránok sa nahralo',
	'info_nom_site_2' => '<b>Názov stránky</b> [Povinné]',
	'info_panne_site_syndique' => 'Syndikovaná stránka mimo prevádzky',
	'info_probleme_grave' => 'chyba u',
	'info_question_proposer_site' => 'Kto môže navrhovať stránky, na ktoré sa odkazuje?',
	'info_retablir_lien' => 'Obnoviť tento odkaz',
	'info_site_attente' => 'Stránka, ktorá čaká na schválenie',
	'info_site_propose' => 'Stránka odoslaná:',
	'info_site_reference' => 'Odkazované stránky online',
	'info_site_refuse' => 'Zamietnutá stránka',
	'info_site_syndique' => 'Táto stránka je syndikovaná.',
	'info_site_valider' => 'Stránky, ktoré čakajú na schválenie',
	'info_sites_referencer' => 'Vložiť odkaz na stránku',
	'info_sites_refuses' => 'Zamietnuté stránky',
	'info_statut_site_1' => 'Táto stránka je:',
	'info_statut_site_2' => 'Publikovaná',
	'info_statut_site_3' => 'Odoslaná',
	'info_statut_site_4' => 'Do koša',
	'info_syndication' => 'syndikácia:',
	'info_syndication_articles' => 'článok (-nky)',
	'item_bloquer_liens_syndiques' => 'Zablokovať syndikované odkazy na overenie',
	'item_gerer_annuaire_site_web' => 'Riadiť priečinok s internetovými stránkami',
	'item_non_bloquer_liens_syndiques' => 'Neblokovať odkazy zo syndikácie',
	'item_non_gerer_annuaire_site_web' => 'Deaktivovať priečinok s internetovými stránkami',
	'item_non_utiliser_syndication' => 'Nepoužívať automatickú syndikáciu',
	'item_utiliser_syndication' => 'Používať automatickú syndikáciu',

	// L
	'label_exporter_avec_mots_cles_1' => 'Exportovať kľúčové slová vo forme tagov',
	'label_exporter_id_parent' => 'Exportovať stránky z rubriky',
	'label_exporter_publie_seulement_1' => 'Exportovať iba publikované stránky',
	'label_fichier_import' => 'Súbor HTML',
	'label_importer_les_tags_1' => 'Nahrať tagy vo forme kľúčových slov',
	'label_importer_statut_publie_1' => 'Automaticky publikovať stránky',
	'lien_mise_a_jour_syndication' => 'Aktualizovať teraz',
	'lien_nouvelle_recuperation' => 'Pokúsiť sa znova získať dáta',
	'lien_purger_syndication' => 'Odstrániť všetky syndikované články',

	// N
	'nombre_articles_syndic' => '@nb@ syndikovaných článkov',

	// S
	'statut_off' => 'Odstránené',
	'statut_prop' => 'Čaká',
	'statut_publie' => 'Publikovaný',
	'syndic_choix_moderation' => 'Čo urobiť s odkazmi z tejto stránky?',
	'syndic_choix_oublier' => 'Čo urobiť s odkazmi, ktoré už viac neexistujú v syndikačnom súbore?',
	'syndic_choix_resume' => 'Niektoré stránky ponúkajú úplné texty svojich článkov. Ak je k dispozícii úplný text, chcete syndikovať:',
	'syndic_lien_obsolete' => 'zastaraný odkaz',
	'syndic_option_miroir' => 'zablokovať ich automaticky',
	'syndic_option_oubli' => 'vymazať ich (po @mois@ mesiacoch)',
	'syndic_option_resume_non' => 'celý obsah článkov (formát HTML)',
	'syndic_option_resume_oui' => 'iba zhrnutie (ako text)',
	'syndic_options' => 'Možnosti syndikácie:',

	// T
	'texte_expliquer_export_bookmarks' => 'Zoznam svojich záložiek môžete exportovať, aby ste ich nahrali do svojho prehliadača alebo internetovej služby na správu záložiek',
	'texte_expliquer_import_bookmarks' => 'Zoznam záložiek vo formáte HTML môžete nahrať zo svojho prehliadača alebo internetovej služby na správu záložiek.',
	'texte_liens_sites_syndiques' => 'Odkazy prichádzajúce zo syndikovaných stránok by mohli
			byť zablokované dopredu; nasledujúce
			nastavenie uvádza predvolené nastavenie
			syndikovaných stránok po ich vytvorení. Potom
			sa aj tak
			dá zablokovať každý odkaz samostatne alebo
			vybrať stránky, z ktorých sa budú prichádzajúce odkazy blokovať automaticky.',
	'texte_messages_publics' => 'Verejné príspevky k článku:',
	'texte_non_fonction_referencement' => 'Môžete sa rozhodnúť nepoužívať túto automatizovanú funkciu a zobrazovať prvky z danej stránky sami.',
	'texte_referencement_automatique' => '<b>Automatické odkazovanie na stránky</b><br />Môžete rýchlo vložiť odkaz na stránku, tak, že uvediete jej adresu alebo adresu jej syndikačného súboru. SPIP automaticky získa údaje o tejto stránke (názov, popis, a pod.).',
	'texte_referencement_automatique_verifier' => 'Pred uložením, prosím, skontrolujte údaje z <tt>@url@</tt>.',
	'texte_syndication' => 'Zoznam nových funkcií sa dá získať automaticky, keď to stránka povoľuje. Na to musíte aktivovať syndikáciu. 
  <blockquote><i>Niektorí poskytovatelia webhostingu deaktivujú túto funkciu; 
 v tom prípade nemôžete využívať syndikáciu obsahu
   zo svojej stránky.</i></blockquote>',
	'titre_articles_syndiques' => 'Syndikované články stiahnuté z tejto stránky',
	'titre_dernier_article_syndique' => 'Najnovšie syndikované články',
	'titre_exporter_bookmarks' => 'Exportovať záložky',
	'titre_importer_bookmarks' => 'Nahrať záložky',
	'titre_importer_exporter_bookmarks' => 'Nahrať a exportovať záložky',
	'titre_page_sites_tous' => 'Stránky, na ktoré odkazujete',
	'titre_referencement_sites' => 'Odkazovanie na stránky a ich syndikácia',
	'titre_site_numero' => 'ČÍSLO STRÁNKY:',
	'titre_sites_proposes' => 'Odoslané stránky',
	'titre_sites_references_rubrique' => 'Odkazované stránky v tejto rubrike',
	'titre_sites_syndiques' => 'Syndikované stránky',
	'titre_sites_tous' => 'Stránky, na ktoré odkazujete',
	'titre_syndication' => 'Syndikácia stránok',
	'tout_voir' => 'Zobraziť všetky syndikované články',

	// U
	'un_article_syndic' => '1 syndikovaný článok'
);

?>
